@@ -35,6 +35,7 @@ use File::Glob qw(:case);
     'gbarr'     => 'Graham Barr <gbarr@cpan.org>',
     'gaas'      => 'Gisle Aas <gaas@cpan.org>',
     'gsar'      => 'Gurusamy Sarathy <gsar@activestate.com>',
+    'hmbrand'   => 'H.Merijn Brand <h.m.brand@xs4all.nl>',
     'ilyam'     => 'Ilya Martynov <ilyam@cpan.org>',
     'ilyaz'     => 'Ilya Zakharevich <ilyaz@cpan.org>',
     'jand'      => 'Jan Dubois <jand@activestate.com>',
@@ -102,8 +103,8 @@ use File::Glob qw(:case);
 @IGNORABLE = qw(
     .cvsignore .dualLivedDiffConfig .gitignore
     ANNOUNCE Announce Artistic AUTHORS BENCHMARK BUGS Build.PL
-    CHANGELOG ChangeLog CHANGES Changes COPYING Copying CREDITS dist.ini
-    GOALS HISTORY INSTALL INSTALL.SKIP LICENSE Makefile.PL
+    CHANGELOG ChangeLog Changelog CHANGES Changes COPYING Copying CREDITS
+    dist.ini GOALS HISTORY INSTALL INSTALL.SKIP LICENSE Makefile.PL
     MANIFEST MANIFEST.SKIP META.yml MYMETA.yml META.json MYMETA.json
     NEW NOTES perlcritic.rc ppport.h README README.PATCHING SIGNATURE
     THANKS TODO Todo VERSION WHATSNEW CONTRIBUTING
@@ -200,7 +201,7 @@ use File::Glob qw(:case);
 
     'Archive::Extract' => {
         'MAINTAINER'   => 'kane',
-        'DISTRIBUTION' => 'BINGOS/Archive-Extract-0.60.tar.gz',
+        'DISTRIBUTION' => 'BINGOS/Archive-Extract-0.68.tar.gz',
         'FILES'        => q[cpan/Archive-Extract],
         'UPSTREAM'     => 'cpan',
         'BUGS'         => 'bug-archive-extract@rt.cpan.org',
@@ -302,10 +303,10 @@ use File::Glob qw(:case);
 
     'B::Lint' => {
         'MAINTAINER'   => 'jjore',
-        'DISTRIBUTION' => 'FLORA/B-Lint-1.14.tar.gz',
-        'FILES'        => q[dist/B-Lint],
+        'DISTRIBUTION' => 'RJBS/B-Lint-1.17.tar.gz',
+        'FILES'        => q[cpan/B-Lint],
         'EXCLUDED'     => ['t/test.pl'],
-        'UPSTREAM'     => 'blead',
+        'UPSTREAM'     => 'cpan',
     },
 
     'base' => {
@@ -323,7 +324,7 @@ use File::Glob qw(:case);
 
     'bignum' => {
         'MAINTAINER'   => 'rafl',
-        'DISTRIBUTION' => 'FLORA/bignum-0.30.tar.gz',
+        'DISTRIBUTION' => 'FLORA/bignum-0.32.tar.gz',
         'FILES'        => q[dist/bignum],
         'EXCLUDED'     => [
             qr{^inc/Module/},
@@ -363,7 +364,7 @@ use File::Glob qw(:case);
 
     'Compress::Raw::Bzip2' => {
         'MAINTAINER'   => 'pmqs',
-        'DISTRIBUTION' => 'PMQS/Compress-Raw-Bzip2-2.058.tar.gz',
+        'DISTRIBUTION' => 'PMQS/Compress-Raw-Bzip2-2.060.tar.gz',
         'FILES'        => q[cpan/Compress-Raw-Bzip2],
         'EXCLUDED'     => [
             qr{^t/Test/},
@@ -374,7 +375,7 @@ use File::Glob qw(:case);
 
     'Compress::Raw::Zlib' => {
         'MAINTAINER'   => 'pmqs',
-        'DISTRIBUTION' => 'PMQS/Compress-Raw-Zlib-2.058.tar.gz',
+        'DISTRIBUTION' => 'PMQS/Compress-Raw-Zlib-2.060.tar.gz',
 
         'FILES'    => q[cpan/Compress-Raw-Zlib],
         'EXCLUDED' => [
@@ -386,9 +387,17 @@ use File::Glob qw(:case);
         'UPSTREAM' => 'cpan',
     },
 
+    'Config::Perl::V' => {
+        'MAINTAINER'   => 'hmbrand',
+        'DISTRIBUTION' => 'HMBRAND/Config-Perl-V-0.17.tgz',
+        'FILES'        => q[cpan/Config-Perl-V],
+        'EXCLUDED'     => ['examples/show-v.pl'],
+        'UPSTREAM'     => 'cpan',
+    },
+
     'constant' => {
         'MAINTAINER'   => 'saper',
-        'DISTRIBUTION' => 'SAPER/constant-1.21.tar.gz',
+        'DISTRIBUTION' => 'SAPER/constant-1.25.tar.gz',
         'FILES'        => q[dist/constant],
         'EXCLUDED'     => [
             qw( t/00-load.t
@@ -403,7 +412,7 @@ use File::Glob qw(:case);
 
     'CPAN' => {
         'MAINTAINER'   => 'andk',
-        'DISTRIBUTION' => 'ANDK/CPAN-1.9800.tar.gz',
+        'DISTRIBUTION' => 'ANDK/CPAN-2.00-TRIAL.tar.gz',
         'FILES'        => q[cpan/CPAN],
         'EXCLUDED'     => [
             qr{^distroprefs/},
@@ -452,7 +461,7 @@ use File::Glob qw(:case);
 
     'CPANPLUS' => {
         'MAINTAINER'   => 'kane',
-        'DISTRIBUTION' => 'BINGOS/CPANPLUS-0.9133.tar.gz',
+        'DISTRIBUTION' => 'BINGOS/CPANPLUS-0.9134.tar.gz',
         'FILES'        => q[cpan/CPANPLUS],
         'EXCLUDED'     => [
             qr{^inc/},
@@ -474,7 +483,7 @@ use File::Glob qw(:case);
 
     'CPANPLUS::Dist::Build' => {
         'MAINTAINER'   => 'bingos',
-        'DISTRIBUTION' => 'BINGOS/CPANPLUS-Dist-Build-0.64.tar.gz',
+        'DISTRIBUTION' => 'BINGOS/CPANPLUS-Dist-Build-0.70.tar.gz',
         'FILES'        => q[cpan/CPANPLUS-Dist-Build],
         'EXCLUDED'     => [
             qr{^inc/},
@@ -523,7 +532,7 @@ use File::Glob qw(:case);
 
     'Data::Dumper' => {
         'MAINTAINER' => 'p5p',    # Not gsar. Not ilyam. Not really smueller
-        'DISTRIBUTION' => 'SMUELLER/Data-Dumper-2.136.tar.gz',
+        'DISTRIBUTION' => 'SMUELLER/Data-Dumper-2.145.tar.gz',
         'FILES'        => q[dist/Data-Dumper],
         'UPSTREAM'     => 'blead',
     },
@@ -594,7 +603,7 @@ use File::Glob qw(:case);
 
     'Digest::SHA' => {
         'MAINTAINER'   => 'mshelor',
-        'DISTRIBUTION' => 'MSHELOR/Digest-SHA-5.73.tar.gz',
+        'DISTRIBUTION' => 'MSHELOR/Digest-SHA-5.84.tar.gz',
         'FILES'        => q[cpan/Digest-SHA],
         'EXCLUDED'     => [
             qw( t/pod.t
@@ -627,7 +636,7 @@ use File::Glob qw(:case);
 
     'Encode' => {
         'MAINTAINER'   => 'dankogai',
-        'DISTRIBUTION' => 'DANKOGAI/Encode-2.47.tar.gz',
+        'DISTRIBUTION' => 'DANKOGAI/Encode-2.49.tar.gz',
         'FILES'        => q[cpan/Encode],
         'UPSTREAM'     => 'cpan',
     },
@@ -657,7 +666,7 @@ use File::Glob qw(:case);
 
     'Env' => {
         'MAINTAINER'   => 'p5p',
-        'DISTRIBUTION' => 'FLORA/Env-1.03.tar.gz',
+        'DISTRIBUTION' => 'FLORA/Env-1.04.tar.gz',
         'FILES'        => q[dist/Env],
         'EXCLUDED'     => [qr{^t/release-.*\.t}],
         'UPSTREAM'     => 'blead',
@@ -738,7 +747,7 @@ use File::Glob qw(:case);
 
     'ExtUtils::MakeMaker' => {
         'MAINTAINER'   => 'mschwern',
-        'DISTRIBUTION' => 'MSCHWERN/ExtUtils-MakeMaker-6.63_02.tar.gz',
+        'DISTRIBUTION' => 'MSCHWERN/ExtUtils-MakeMaker-6.64.tar.gz',
         'FILES'        => q[cpan/ExtUtils-MakeMaker],
         'EXCLUDED'     => [
             qr{^t/lib/Test/},
@@ -766,7 +775,7 @@ use File::Glob qw(:case);
 
     'perlfaq' => {
         'MAINTAINER'   => 'perlfaq',
-        'DISTRIBUTION' => 'LLAP/perlfaq-5.0150041.tar.gz',
+        'DISTRIBUTION' => 'LLAP/perlfaq-5.0150042.tar.gz',
         'FILES'        => q[cpan/perlfaq],
         'EXCLUDED'     => [
             qw( t/release-pod-syntax.t
@@ -797,21 +806,21 @@ use File::Glob qw(:case);
 
     'File::CheckTree' => {
         'MAINTAINER'   => 'p5p',
-        'DISTRIBUTION' => 'FLORA/File-CheckTree-4.41.tar.gz',
-        'FILES'        => q[dist/File-CheckTree],
+        'DISTRIBUTION' => 'RJBS/File-CheckTree-4.42.tar.gz',
+        'FILES'        => q[cpan/File-CheckTree],
         'EXCLUDED'     => [qr{^t/release-.*\.t}],
-        'UPSTREAM'     => 'blead',
+        'UPSTREAM'     => 'cpan',
     },
 
     'File::DosGlob' => {
         'MAINTAINER' => 'p5p',
-        'FILES'      => q[lib/File/DosGlob.{pm,t}],
+        'FILES'      => q[ext/File-DosGlob],
         'UPSTREAM'   => 'blead',
     },
 
     'File::Fetch' => {
         'MAINTAINER'   => 'kane',
-        'DISTRIBUTION' => 'BINGOS/File-Fetch-0.36.tar.gz',
+        'DISTRIBUTION' => 'BINGOS/File-Fetch-0.38.tar.gz',
         'FILES'        => q[cpan/File-Fetch],
         'UPSTREAM'     => 'cpan',
     },
@@ -830,7 +839,7 @@ use File::Glob qw(:case);
 
     'File::Path' => {
         'MAINTAINER'   => 'dland',
-        'DISTRIBUTION' => 'DLAND/File-Path-2.08.tar.gz',
+        'DISTRIBUTION' => 'DLAND/File-Path-2.09.tar.gz',
         'FILES'        => q[cpan/File-Path],
         'EXCLUDED'     => [
             qw( eg/setup-extra-tests
@@ -852,7 +861,7 @@ use File::Glob qw(:case);
 
     'File::Temp' => {
         'MAINTAINER'   => 'tjenness',
-        'DISTRIBUTION' => 'TJENNESS/File-Temp-0.22.tar.gz',
+        'DISTRIBUTION' => 'TJENNESS/File-Temp-0.23.tar.gz',
         'FILES'        => q[cpan/File-Temp],
         'EXCLUDED'     => [
             qw( misc/benchmark.pl
@@ -939,7 +948,7 @@ use File::Glob qw(:case);
 
     'Getopt::Long' => {
         'MAINTAINER'   => 'jv',
-        'DISTRIBUTION' => 'JV/Getopt-Long-2.38.tar.gz',
+        'DISTRIBUTION' => 'JV/Getopt-Long-2.39.tar.gz',
         'FILES'        => q[cpan/Getopt-Long],
         'EXCLUDED'     => [
             qr{^examples/},
@@ -971,7 +980,7 @@ use File::Glob qw(:case);
 
     'HTTP::Tiny' => {
         'MAINTAINER'   => 'dagolden',
-        'DISTRIBUTION' => 'DAGOLDEN/HTTP-Tiny-0.024.tar.gz',
+        'DISTRIBUTION' => 'DAGOLDEN/HTTP-Tiny-0.025.tar.gz',
         'FILES'        => q[cpan/HTTP-Tiny],
         'EXCLUDED'     => [
             't/00-report-prereqs.t',
@@ -1025,7 +1034,7 @@ use File::Glob qw(:case);
 
     'IO-Compress' => {
         'MAINTAINER'   => 'pmqs',
-        'DISTRIBUTION' => 'PMQS/IO-Compress-2.058.tar.gz',
+        'DISTRIBUTION' => 'PMQS/IO-Compress-2.060.tar.gz',
         'FILES'        => q[cpan/IO-Compress],
         'EXCLUDED'     => [qr{t/Test/}],
         'UPSTREAM'     => 'cpan',
@@ -1040,7 +1049,7 @@ use File::Glob qw(:case);
 
     'IPC::Cmd' => {
         'MAINTAINER'   => 'kane',
-        'DISTRIBUTION' => 'BINGOS/IPC-Cmd-0.78.tar.gz',
+        'DISTRIBUTION' => 'BINGOS/IPC-Cmd-0.80.tar.gz',
         'FILES'        => q[cpan/IPC-Cmd],
         'UPSTREAM'     => 'cpan',
     },
@@ -1065,7 +1074,7 @@ use File::Glob qw(:case);
 
     'JSON::PP' => {
         'MAINTAINER'   => 'makamaka',
-        'DISTRIBUTION' => 'MAKAMAKA/JSON-PP-2.27200.tar.gz',
+        'DISTRIBUTION' => 'MAKAMAKA/JSON-PP-2.27202.tar.gz',
         'FILES'        => q[cpan/JSON-PP],
         'EXCLUDED'     => [
             't/900_pod.t',    # Pod testing
@@ -1101,7 +1110,7 @@ use File::Glob qw(:case);
 
     'Locale-Codes' => {
         'MAINTAINER'   => 'sbeck',
-        'DISTRIBUTION' => 'SBECK/Locale-Codes-3.23.tar.gz',
+        'DISTRIBUTION' => 'SBECK/Locale-Codes-3.25.tar.gz',
         'FILES'        => q[cpan/Locale-Codes],
         'EXCLUDED'     => [
             qw( t/pod_coverage.t
@@ -1116,7 +1125,7 @@ use File::Glob qw(:case);
 
     'Locale::Maketext' => {
         'MAINTAINER'   => 'ferreira',
-        'DISTRIBUTION' => 'TODDR/Locale-Maketext-1.22.tar.gz',
+        'DISTRIBUTION' => 'TODDR/Locale-Maketext-1.23.tar.gz',
         'FILES'        => q[dist/Locale-Maketext],
         'EXCLUDED'     => [
             qw(
@@ -1138,14 +1147,14 @@ use File::Glob qw(:case);
 
     'Log::Message' => {
         'MAINTAINER'   => 'kane',
-        'DISTRIBUTION' => 'BINGOS/Log-Message-0.04.tar.gz',
+        'DISTRIBUTION' => 'BINGOS/Log-Message-0.06.tar.gz',
         'FILES'        => q[cpan/Log-Message],
         'UPSTREAM'     => 'cpan',
     },
 
     'Log::Message::Simple' => {
         'MAINTAINER'   => 'kane',
-        'DISTRIBUTION' => 'BINGOS/Log-Message-Simple-0.08.tar.gz',
+        'DISTRIBUTION' => 'BINGOS/Log-Message-Simple-0.10.tar.gz',
         'FILES'        => q[cpan/Log-Message-Simple],
         'UPSTREAM'     => 'cpan',
     },
@@ -1262,14 +1271,14 @@ use File::Glob qw(:case);
 
     'Module::CoreList' => {
         'MAINTAINER'   => 'bingos',
-        'DISTRIBUTION' => 'BINGOS/Module-CoreList-2.77.tar.gz',
+        'DISTRIBUTION' => 'BINGOS/Module-CoreList-2.84.tar.gz',
         'FILES'        => q[dist/Module-CoreList],
         'UPSTREAM'     => 'blead',
     },
 
     'Module::Load' => {
         'MAINTAINER'   => 'kane',
-        'DISTRIBUTION' => 'BINGOS/Module-Load-0.22.tar.gz',
+        'DISTRIBUTION' => 'BINGOS/Module-Load-0.24.tar.gz',
         'FILES'        => q[cpan/Module-Load],
         'UPSTREAM'     => 'cpan',
     },
@@ -1301,7 +1310,7 @@ use File::Glob qw(:case);
 
     'Module::Pluggable' => {
         'MAINTAINER'   => 'simonw',
-        'DISTRIBUTION' => 'SIMONW/Module-Pluggable-4.5.tar.gz',
+        'DISTRIBUTION' => 'SIMONW/Module-Pluggable-4.7.tar.gz',
         'FILES'        => q[cpan/Module-Pluggable],
         'UPSTREAM'     => 'cpan',
         'CUSTOMIZED'   => ['Makefile.PL'],
@@ -1321,8 +1330,12 @@ use File::Glob qw(:case);
 
     'Net::Ping' => {
         'MAINTAINER'   => 'smpeters',
-        'DISTRIBUTION' => 'SMPETERS/Net-Ping-2.36.tar.gz',
+        'DISTRIBUTION' => 'SMPETERS/Net-Ping-2.41.tar.gz',
         'FILES'        => q[dist/Net-Ping],
+        'EXCLUDED'     => [
+            qr{^.travis.yml},
+            qr{^README.md},
+        ],
         'UPSTREAM'     => 'blead',
     },
 
@@ -1336,7 +1349,7 @@ use File::Glob qw(:case);
 
     'Object::Accessor' => {
         'MAINTAINER'   => 'kane',
-        'DISTRIBUTION' => 'BINGOS/Object-Accessor-0.44.tar.gz',
+        'DISTRIBUTION' => 'BINGOS/Object-Accessor-0.46.tar.gz',
         'FILES'        => q[cpan/Object-Accessor],
         'UPSTREAM'     => 'cpan',
     },
@@ -1390,7 +1403,7 @@ use File::Glob qw(:case);
 
     'PathTools' => {
         'MAINTAINER'   => 'kwilliams',
-        'DISTRIBUTION' => 'SMUELLER/PathTools-3.33.tar.gz',
+        'DISTRIBUTION' => 'SMUELLER/PathTools-3.40.tar.gz',
         'FILES'        => q[dist/Cwd],
         'EXCLUDED'     => [qr{^t/lib/Test/}],
         'UPSTREAM'     => "blead",
@@ -1452,9 +1465,9 @@ use File::Glob qw(:case);
 
     'Perl::OSType' => {
         'MAINTAINER'   => 'dagolden',
-        'DISTRIBUTION' => 'DAGOLDEN/Perl-OSType-1.002.tar.gz',
+        'DISTRIBUTION' => 'DAGOLDEN/Perl-OSType-1.003.tar.gz',
         'FILES'        => q[cpan/Perl-OSType],
-        'EXCLUDED'     => [qr/^xt/],
+        'EXCLUDED'     => [qr/^xt/, qr{^t/00-}],
         'UPSTREAM'     => 'cpan',
     },
 
@@ -1495,6 +1508,13 @@ use File::Glob qw(:case);
         'UPSTREAM'   => undef,
     },
 
+    'Pod::Checker' => {
+        'MAINTAINER' => 'marekr',
+        'DISTRIBUTION' => 'MAREKR/Pod-Checker-1.60.tar.gz',
+        'FILES'        => q[cpan/Pod-Checker],
+        'UPSTREAM'     => 'cpan',
+    },
+
     'Pod::Escapes' => {
         'MAINTAINER'   => 'arandal',
         'DISTRIBUTION' => 'SBURKE/Pod-Escapes-1.04.tar.gz',
@@ -1516,7 +1536,7 @@ use File::Glob qw(:case);
 
     'Pod::LaTeX' => {
         'MAINTAINER'   => 'tjenness',
-        'DISTRIBUTION' => 'TJENNESS/Pod-LaTeX-0.60.tar.gz',
+        'DISTRIBUTION' => 'TJENNESS/Pod-LaTeX-0.61.tar.gz',
         'FILES'        => q[cpan/Pod-LaTeX],
         'EXCLUDED'     => ['t/require.t'],
         'UPSTREAM'     => undef,
@@ -1524,14 +1544,14 @@ use File::Glob qw(:case);
 
     'Pod::Parser' => {
         'MAINTAINER' => 'marekr',
-        'DISTRIBUTION' => 'MAREKR/Pod-Parser-1.51.tar.gz',
+        'DISTRIBUTION' => 'MAREKR/Pod-Parser-1.60.tar.gz',
         'FILES'        => q[cpan/Pod-Parser],
         'UPSTREAM'     => 'cpan',
     },
 
     'Pod::Perldoc' => {
         'MAINTAINER'   => 'mallen',
-        'DISTRIBUTION' => 'MALLEN/Pod-Perldoc-3.17.tar.gz',
+        'DISTRIBUTION' => 'MALLEN/Pod-Perldoc-3.19.tar.gz',
         'FILES'        => q[cpan/Pod-Perldoc],
 
         # in blead, the perldoc executable is generated by perldoc.PL
@@ -1544,14 +1564,21 @@ use File::Glob qw(:case);
 
     'Pod::Simple' => {
         'MAINTAINER'   => 'arandal',
-        'DISTRIBUTION' => 'DWHEELER/Pod-Simple-3.23.tar.gz',
+        'DISTRIBUTION' => 'DWHEELER/Pod-Simple-3.26.tar.gz',
         'FILES'        => q[cpan/Pod-Simple],
         'UPSTREAM'     => 'cpan',
     },
 
+    'Pod::Usage' => {
+        'MAINTAINER' => 'marekr',
+        'DISTRIBUTION' => 'MAREKR/Pod-Usage-1.61.tar.gz',
+        'FILES'        => q[cpan/Pod-Usage],
+        'UPSTREAM'     => 'cpan',
+    },
+
     'podlators' => {
         'MAINTAINER'   => 'rra',
-        'DISTRIBUTION' => 'RRA/podlators-2.4.2.tar.gz',
+        'DISTRIBUTION' => 'RRA/podlators-2.5.1.tar.gz',
         'FILES'        => q[cpan/podlators pod/perlpodstyle.pod],
 
         # The perl distribution has pod2man.PL and pod2text.PL,  which are
@@ -1588,14 +1615,14 @@ use File::Glob qw(:case);
 
     'Safe' => {
         'MAINTAINER'   => 'rgarcia',
-        'DISTRIBUTION' => 'RGARCIA/Safe-2.33.tar.gz',
+        'DISTRIBUTION' => 'RGARCIA/Safe-2.35.tar.gz',
         'FILES'        => q[dist/Safe],
         'UPSTREAM'     => 'blead',
     },
 
     'Scalar-List-Utils' => {
         'MAINTAINER'   => 'gbarr',
-        'DISTRIBUTION' => 'PEVANS/Scalar-List-Utils-1.25.tar.gz',
+        'DISTRIBUTION' => 'PEVANS/Scalar-List-Utils-1.27.tar.gz',
 
         # Note that perl uses its own version of Makefile.PL
         'FILES'    => q[cpan/List-Util],
@@ -1637,7 +1664,7 @@ use File::Glob qw(:case);
 
     'Socket' => {
         'MAINTAINER'   => 'pevans',
-        'DISTRIBUTION' => 'PEVANS/Socket-2.006.tar.gz',
+        'DISTRIBUTION' => 'PEVANS/Socket-2.009.tar.gz',
         'FILES'        => q[cpan/Socket],
         'UPSTREAM'     => 'cpan',
     },
@@ -1676,12 +1703,20 @@ use File::Glob qw(:case);
 
     'Term::ANSIColor' => {
         'MAINTAINER'   => 'rra',
-        'DISTRIBUTION' => 'RRA/Term-ANSIColor-3.02.tar.gz',
+        'DISTRIBUTION' => 'RRA/Term-ANSIColor-4.02.tar.gz',
         'FILES'        => q[cpan/Term-ANSIColor],
         'EXCLUDED'     => [
             qr{^tests/},
-            qw( t/pod-spelling.t
+            qr{^examples/},
+            qr{^t/data/},
+            qw( t/aliases-env.t
+                t/critic.t
+                t/minimum-version.t
+                t/pod-spelling.t
+                t/pod-coverage.t
                 t/pod.t
+                t/strict.t
+                t/synopsis.t
                 ),
         ],
         'UPSTREAM' => 'cpan',
@@ -1712,21 +1747,21 @@ use File::Glob qw(:case);
 
     'Term::UI' => {
         'MAINTAINER'   => 'kane',
-        'DISTRIBUTION' => 'BINGOS/Term-UI-0.32.tar.gz',
+        'DISTRIBUTION' => 'BINGOS/Term-UI-0.34.tar.gz',
         'FILES'        => q[cpan/Term-UI],
         'UPSTREAM'     => 'cpan',
     },
 
     'Test' => {
         'MAINTAINER'   => 'jesse',
-        'DISTRIBUTION' => 'JESSE/Test-1.25_02.tar.gz',
+        'DISTRIBUTION' => 'JESSE/Test-1.26.tar.gz',
         'FILES'        => q[cpan/Test],
         'UPSTREAM'     => 'cpan',
     },
 
     'Test::Harness' => {
         'MAINTAINER'   => 'andya',
-        'DISTRIBUTION' => 'OVID/Test-Harness-3.25.tar.gz',
+        'DISTRIBUTION' => 'OVID/Test-Harness-3.26.tar.gz',
         'FILES'        => q[cpan/Test-Harness],
         'EXCLUDED'     => [
             qr{^examples/},
@@ -1740,63 +1775,8 @@ use File::Glob qw(:case);
                 t/lib/if.pm
                 ),
         ],
-        'MAP'        => {
-            ''                    => 'cpan/Test-Harness/',
-            't/compat/env.opts.t' => 'cpan/Test-Harness/t/compat/env_opts.t'
-        },
+        'CUSTOMIZED' => [ 't/source.t' ],
         'UPSTREAM'   => 'cpan',
-        'CUSTOMIZED' => [
-            qw( lib/App/Prove.pm
-                lib/App/Prove/State.pm
-                lib/App/Prove/State/Result.pm
-                lib/App/Prove/State/Result/Test.pm
-                lib/TAP/Base.pm
-                lib/TAP/Formatter/Base.pm
-                lib/TAP/Formatter/Color.pm
-                lib/TAP/Formatter/Console.pm
-                lib/TAP/Formatter/Console/ParallelSession.pm
-                lib/TAP/Formatter/Console/Session.pm
-                lib/TAP/Formatter/File.pm
-                lib/TAP/Formatter/File/Session.pm
-                lib/TAP/Formatter/Session.pm
-                lib/TAP/Harness.pm
-                lib/TAP/Object.pm
-                lib/TAP/Parser.pm
-                lib/TAP/Parser/Aggregator.pm
-                lib/TAP/Parser/Grammar.pm
-                lib/TAP/Parser/Iterator.pm
-                lib/TAP/Parser/Iterator/Array.pm
-                lib/TAP/Parser/Iterator/Process.pm
-                lib/TAP/Parser/Iterator/Stream.pm
-                lib/TAP/Parser/IteratorFactory.pm
-                lib/TAP/Parser/Multiplexer.pm
-                lib/TAP/Parser/Result.pm
-                lib/TAP/Parser/Result/Bailout.pm
-                lib/TAP/Parser/Result/Comment.pm
-                lib/TAP/Parser/Result/Plan.pm
-                lib/TAP/Parser/Result/Pragma.pm
-                lib/TAP/Parser/Result/Test.pm
-                lib/TAP/Parser/Result/Unknown.pm
-                lib/TAP/Parser/Result/Version.pm
-                lib/TAP/Parser/Result/YAML.pm
-                lib/TAP/Parser/ResultFactory.pm
-                lib/TAP/Parser/Scheduler.pm
-                lib/TAP/Parser/Scheduler/Job.pm
-                lib/TAP/Parser/Scheduler/Spinner.pm
-                lib/TAP/Parser/Source.pm
-                lib/TAP/Parser/SourceHandler.pm
-                lib/TAP/Parser/SourceHandler/Executable.pm
-                lib/TAP/Parser/SourceHandler/File.pm
-                lib/TAP/Parser/SourceHandler/Handle.pm
-                lib/TAP/Parser/SourceHandler/Perl.pm
-                lib/TAP/Parser/SourceHandler/RawTAP.pm
-                lib/TAP/Parser/Utils.pm
-                lib/TAP/Parser/YAMLish/Reader.pm
-                lib/TAP/Parser/YAMLish/Writer.pm
-                lib/Test/Harness.pm
-                t/source.t
-                ),
-        ],
     },
 
     'Test::Simple' => {
@@ -1851,7 +1831,7 @@ use File::Glob qw(:case);
 
     'Text::ParseWords' => {
         'MAINTAINER'   => 'chorny',
-        'DISTRIBUTION' => 'CHORNY/Text-ParseWords-3.27.zip',
+        'DISTRIBUTION' => 'CHORNY/Text-ParseWords-3.28.tar.gz',
         'FILES'        => q[cpan/Text-ParseWords],
         'EXCLUDED'     => ['t/pod.t'],
 
@@ -1865,7 +1845,7 @@ use File::Glob qw(:case);
 
     'Text::Soundex' => {
         'MAINTAINER'   => 'markm',
-        'DISTRIBUTION' => 'MARKM/Text-Soundex-3.03.tar.gz',
+        'DISTRIBUTION' => 'RJBS/Text-Soundex-3.04.tar.gz',
         'FILES'        => q[cpan/Text-Soundex],
         'MAP'          => {
             '' => 'cpan/Text-Soundex/',
@@ -1896,7 +1876,7 @@ use File::Glob qw(:case);
 
     'Thread::Queue' => {
         'MAINTAINER'   => 'jdhedden',
-        'DISTRIBUTION' => 'JDHEDDEN/Thread-Queue-3.01.tar.gz',
+        'DISTRIBUTION' => 'JDHEDDEN/Thread-Queue-3.02.tar.gz',
         'FILES'        => q[dist/Thread-Queue],
         'EXCLUDED'     => [
             qr{^examples/},
@@ -1938,7 +1918,7 @@ use File::Glob qw(:case);
 
     'threads::shared' => {
         'MAINTAINER'   => 'jdhedden',
-        'DISTRIBUTION' => 'JDHEDDEN/threads-shared-1.42.tar.gz',
+        'DISTRIBUTION' => 'JDHEDDEN/threads-shared-1.43.tar.gz',
         'FILES'        => q[dist/threads-shared],
         'EXCLUDED'     => [
             qw( examples/class.pl
@@ -2011,7 +1991,7 @@ use File::Glob qw(:case);
 
     'Unicode::Collate' => {
         'MAINTAINER'   => 'sadahiro',
-        'DISTRIBUTION' => 'SADAHIRO/Unicode-Collate-0.93.tar.gz',
+        'DISTRIBUTION' => 'SADAHIRO/Unicode-Collate-0.97.tar.gz',
         'FILES'        => q[cpan/Unicode-Collate],
         'EXCLUDED'     => [
             qr{N$},
@@ -2047,7 +2027,7 @@ use File::Glob qw(:case);
 
     'version' => {
         'MAINTAINER'   => 'jpeacock',
-        'DISTRIBUTION' => 'JPEACOCK/version-0.9901.tar.gz',
+        'DISTRIBUTION' => 'JPEACOCK/version-0.9902.tar.gz',
         'FILES'        => q[lib/version.pm lib/version.pod lib/version],
         'EXCLUDED' => [
             qr{^t/.*\.t$},
@@ -2099,14 +2079,14 @@ use File::Glob qw(:case);
 
     'Win32' => {
         'MAINTAINER'   => 'jand',
-        'DISTRIBUTION' => "JDB/Win32-0.45.tar.gz",
+        'DISTRIBUTION' => "JDB/Win32-0.47.tar.gz",
         'FILES'        => q[cpan/Win32],
         'UPSTREAM'     => 'cpan',
     },
 
     'Win32API::File' => {
         'MAINTAINER'   => 'chorny',
-        'DISTRIBUTION' => 'CHORNY/Win32API-File-0.1200.tar.gz',
+        'DISTRIBUTION' => 'CHORNY/Win32API-File-0.1201.tar.gz',
         'FILES'        => q[cpan/Win32API-File],
         'EXCLUDED'     => [
             qr{^ex/},
