@@ -12,6 +12,17 @@
  * Each section names the header file that the functions "belong" to.
  */
 
+/* ------------------------------- av.h ------------------------------- */
+
+PERL_STATIC_INLINE I32
+S_av_top_index(pTHX_ AV *av)
+{
+    PERL_ARGS_ASSERT_AV_TOP_INDEX;
+    assert(SvTYPE(av) == SVt_PVAV);
+
+    return AvFILL(av);
+}
+
 /* ------------------------------- cv.h ------------------------------- */
 
 PERL_STATIC_INLINE I32 *
@@ -35,7 +46,7 @@ S_ReANY(const REGEXP * const re)
 PERL_STATIC_INLINE SV *
 S_SvREFCNT_inc(SV *sv)
 {
-    if (sv)
+    if (LIKELY(sv != NULL))
 	SvREFCNT(sv)++;
     return sv;
 }
@@ -48,13 +59,13 @@ S_SvREFCNT_inc_NN(SV *sv)
 PERL_STATIC_INLINE void
 S_SvREFCNT_inc_void(SV *sv)
 {
-    if (sv)
+    if (LIKELY(sv != NULL))
 	SvREFCNT(sv)++;
 }
 PERL_STATIC_INLINE void
 S_SvREFCNT_dec(pTHX_ SV *sv)
 {
-    if (sv) {
+    if (LIKELY(sv != NULL)) {
 	U32 rc = SvREFCNT(sv);
 	if (rc > 1)
 	    SvREFCNT(sv) = rc - 1;
